@@ -1,6 +1,5 @@
 import OpenDirectory
 from PyObjCTools.TestSupport import TestCase
-import objc
 
 
 class TestOpenDirectory(TestCase):
@@ -8,7 +7,7 @@ class TestOpenDirectory(TestCase):
         self.assertIsInstance(OpenDirectory.ODFrameworkErrorDomain, str)
 
     def testProtocols(self):
-        objc.protocolNamed("ODQueryDelegate")
+        self.assertProtocolExists("ODQueryDelegate")
 
     def testIntegration(self):
         import CFOpenDirectory
@@ -18,4 +17,9 @@ class TestOpenDirectory(TestCase):
                 cfod = getattr(CFOpenDirectory, nm)
                 od = getattr(OpenDirectory, nm)
 
-                self.assertIs(cfod, od)
+                self.assertIs(cfod, od, f"{nm!r}, {type(cfod)}, {type(od)}")
+
+
+class TestCallableMetadata(TestCase):
+    def test_callable_metadata_is_sane(self):
+        self.assertCallableMetadataIsSane(OpenDirectory)
